@@ -55,17 +55,14 @@ public:
    virtual ~Storage();
    enum StorageSystem { StorageSystemLegacy, StorageSystemPacked };
    //must be called before the first call to instance()
-   static void setSystem(StorageSystem system);
-   void setMaxStorage(int maxMB=-1);
    
-   static Storage *instance();
+   static Storage *CreateInstance(StorageSystem system, int storageLimit);
    
    //must be called before operation starts. Set all options (RootDir, maxStorage) before.
-   void init();   
    virtual void cleanUp() = 0;
    
    virtual void getFilename(char *buffer, int bufLength, PageID page);
-   void prepareDirectory(tChannelID chan);
+   virtual void prepareDirectory(tChannelID chan);
    
    virtual StorageHandle openForWriting(PageID page) = 0;
    virtual StorageHandle openForReading(PageID page, bool countAsAccess) = 0;
@@ -73,27 +70,24 @@ public:
    virtual ssize_t read(void *ptr, size_t size, StorageHandle stream) = 0;
    virtual void close(StorageHandle stream) = 0;
 protected:
-   virtual void initMaxStorage(int maxMB=-1) = 0;
-   
    Storage();
    int cleanSubDir(const char *dir);
    int doCleanUp();
    virtual int actualFileSize(int netFileSize) { return netFileSize; }
-   static Storage *s_self;
    void freeSpace();
    bool exists(const char* file);
    
    long byteCount;
    cString currentDir;
 private:
-   static StorageSystem system;
-   int storageOption;
    bool failedFreeSpace;
 };
 
 class LegacyStorage : public Storage {
+private:
+   void initMaxStorage(int maxMB=-1);
 public:
-   LegacyStorage();
+   LegacyStorage(int maxMB);
    virtual ~LegacyStorage();
    virtual void cleanUp();
    
@@ -105,7 +99,6 @@ public:
    virtual void close(StorageHandle stream)
      { ::close((int)stream); }
 protected:
-   virtual void initMaxStorage(int maxMB=-1);
    void registerFile(PageID page);
    virtual int actualFileSize(int netFileSize);
    //int maxPages;
@@ -116,9 +109,7 @@ protected:
 
 class PackedStorage : public LegacyStorage {
 public:
-   PackedStorage();
-   //virtual void setMaxStorage(int maxMB=-1);
-   //virtual void cleanUp();
+   PackedStorage(int maxMB);
    
    virtual void getFilename(char *buffer, int bufLength, PageID page);
    virtual StorageHandle openForWriting(PageID page);
@@ -143,12 +134,13 @@ class cTelePage {
   unsigned char lang;
   PageID page;
   unsigned char pagebuf[27*40];
-  char Directory [255];
+  Storage* storage;
  public:
-  cTelePage(PageID page, uchar flags, uchar lang, int mag);
+  cTelePage(PageID page, uchar flags, uchar lang, int mag, Storage *s);
   ~cTelePage();
   void SetLine(int, uchar*);
   void save();
+  bool IsTopTextPage();
  };
 
 class cRingTxtFrames : public cRingBufferFrame {
@@ -157,23 +149,23 @@ class cRingTxtFrames : public cRingBufferFrame {
   ~cRingTxtFrames() { Clear(); };
   void Wait(void) { WaitForGet(); };
   void Signal(void) { EnableGet(); };
-  bool Check(int Size) { return (Free() >= Size); };
 };
 
 class cTxtReceiver : public cReceiver, public cThread {
 private:
    void DecodeTXT(uchar*);
    uchar unham16 (uchar*);
-   tChannelID chan;
    cTelePage *TxtPage;
+   void SaveAndDeleteTxtPage();
+   bool storeTopText;
+   cRingTxtFrames buffer;
+   Storage *storage;
 protected:
    virtual void Activate(bool On);
    virtual void Receive(uchar *Data, int Length);
-   void Action();
-   cRingTxtFrames buffer;
-   bool running;
+   virtual void Action();
 public:
-   cTxtReceiver(int TPid, tChannelID chan);
+   cTxtReceiver(int TPid, tChannelID chan, bool storeTopText, Storage* storage);
    virtual ~cTxtReceiver();
    virtual void Stop();
 };
@@ -181,11 +173,12 @@ public:
 class cTxtStatus : public cStatus {
 private:
    cTxtReceiver *receiver;
-   tChannelID currentLiveChannel;
+   bool storeTopText;
+   Storage* storage;
 protected:
    virtual void ChannelSwitch(const cDevice *Device, int ChannelNumber);
 public:
-   cTxtStatus(void);
+   cTxtStatus(bool storeTopText, Storage* storage);
    ~cTxtStatus();
 };
 
